<?php

/**
 * Displays the Email Petitions table page
 * Also handles deleting petitions
 * HTML for the Email Petitions page is loaded from admin-petitions-view.php
 */
function dk_speakup_petitions_page() {
	// check security: ensure user has authority
	if ( !current_user_can( 'publish_posts' ) ) wp_die( 'Insufficient privileges: You need to be an editor to do that.' );

	global $wpdb;
	$action = isset( $_REQUEST['action'] ) ? $_REQUEST['action'] : '';
	$id = isset( $_REQUEST['id'] ) ? $_REQUEST['id'] : '';
	$current_url = site_url( 'wp-admin/admin.php?page=dk_speakup' );
	$options = get_option( 'dk_speakup_options' );

	// set variables for paged record display and limit values in db query
	// request values may be submitted either by html links (pagination.php) or by javascript (admin.js)
	$paged = isset( $_REQUEST['paged'] ) ? $_REQUEST['paged'] : '1';
	$total_pages = isset ( $_REQUEST['total_pages'] ) ? $_REQUEST['total_pages'] : '1';
	$current_page = dk_speakup_current_paged( $paged, $total_pages );
	$query_limit = $options['petitions_rows'];
	$query_start = ( $current_page * $query_limit ) - $query_limit;

	// construct db table name
	$db_petitions = $wpdb->prefix . "dk_speakup_petitions";
	$db_signatures = $wpdb->prefix . "dk_speakup_signatures";

	// set up default page display strings
	$page_title = __( 'Email Petitions', 'dk_speakup' );
	$message_update = '';

	switch ( $action ) {
		case 'delete' :
			// security: ensure user has intention
			check_admin_referer( 'dk_speakup-delete_petition' . $id );

			// Do delete stuff
			// delete petition from the db
			$sql_petitions = "
				DELETE FROM `$db_petitions`
				WHERE `id` = '$id'
			";
			$wpdb->query( $sql_petitions );

			// delete petition's signatures from the db
			$sql_signatures = "
				DELETE FROM `$db_signatures`
				WHERE `petitions_id` = '$id'
			";
			$wpdb->query( $sql_signatures );

			// Do page display stuff
			// count number of petitions in db
			$sql_get_count = "
				SELECT `id`
				FROM `$db_petitions`
			";
			$results_get_count = $wpdb->get_results( $sql_get_count );
			$count = count( $results_get_count );

			// query petitions and number of signatures for each
			$sql = "
				SELECT $db_petitions.id, $db_petitions.petition_title, $db_petitions.signature_goal, COUNT( $db_signatures.id ) AS 'signatures'
				FROM $db_petitions
				LEFT JOIN $db_signatures
					ON $db_petitions.id = $db_signatures.petitions_id
					AND ( $db_signatures.confirmed = '' OR $db_signatures.confirmed = '1' )
				GROUP BY $db_petitions.id
				ORDER BY `id` DESC LIMIT $query_start, $query_limit
			";
			$results = $wpdb->get_results( $sql );

			// set up page display strings
			$message_update = __( 'Petition deleted.', 'dk_speakup' );
			break;

		default :
			// count number of petitions in db
			$sql_get_count = "
				SELECT `id`
				FROM `$db_petitions`
			";
			$results_get_count = $wpdb->get_results( $sql_get_count );
			$count = count( $results_get_count );

			// query petitions and number of signatures for each
			$sql = "
				SELECT $db_petitions.id, $db_petitions.petition_title, $db_petitions.signature_goal, COUNT( $db_signatures.id ) AS 'signatures'
				FROM $db_petitions
				LEFT JOIN $db_signatures
					ON $db_petitions.id = $db_signatures.petitions_id
					AND ( $db_signatures.confirmed = '' OR $db_signatures.confirmed = '1' )
				GROUP BY $db_petitions.id
				ORDER BY `id` DESC LIMIT $query_start, $query_limit
			";
			$results = $wpdb->get_results( $sql );
	}
	// link URL for "Add New" button in h2
	$addnew_url = esc_url( site_url() . '/wp-admin/admin.php?page=dk_speakup_edit' );

	// display the Petitions table
	include_once( dirname( __FILE__ ) . '/admin-petitions-view.php' );
}

?>