<?php

/**
 * Create pagination links for paging through large numbers of rows on admin table views
 * echoes the resulting html
 *
 * @param $limit (int) number of rows to display in a single view
 * @param $count (int) total number of records retrieved from query
 * @param $page_handle (string) handle of currently loaded page
 * @param $current_page (int) "paged" value of the url that is currently displayed
 * @param $base_url (string) URL of current page with minimal get variables for constructing text links
 * @param $use_form (bool) whether to display the form input for switching pages
 */
function pagination($limit, $count, $page_handle, $current_page, $base_url, $use_form) {
	// round up the page count so we get an integer
	$total_pages = ceil( $count / $limit );

	if ( $total_pages <= 1 ) {
		$pager_html  = '<div class="tablenav-pages one-page">';
	}
	else {
		$pager_html  = '<div class="tablenav-pages">';
	}
	$pager_html  .= '<form action="" method="post" id="dk-speakup-pager">';
	$pager_html  .= '<input type="hidden" name="dk-speakup-total-pages" id="dk-speakup-total-pages" value="' . $total_pages . '">';
	$pager_html  .= '<input type="hidden" name="dk-speakup-page" id="dk-speakup-page" value="' . $page_handle . '">';
	$pager_html  .= '<span class="displaying-num">' . $count . ' ' . __('items') . '</span>';

	// first page and previous page links
	if ( $current_page == 1 ) {
      $pager_html .= '<a class="first-page disabled" href="">&laquo;</a> ';
		$pager_html .= '<a class="prev-page disabled" href="">&lsaquo;</a> ';
   }
	else {
      $pager_html .= '<a class="first-page" href="' . $base_url . '&paged=1' . '&total_pages=' . $total_pages . '">&laquo;</a> ';
		$pager_html .= '<a class="prev-page" href="' . $base_url . '&paged=' . ( $current_page - 1 ) . '&total_pages=' . $total_pages . '">&lsaquo;</a> ';
    }

	// #page of #pages text, optionally with a form input for changing values
	if ($use_form == true ) {
		$pager_html .= '<span class="paging-input"><input class="current-page" name="dk-speakup-paged" id="dk-speakup-paged" value="' . $current_page . '" size="1" maxlength="4" type="text"> ' . __('of') . ' <span class="total-pages">' . $total_pages . ' </span></span>';
	}
	else {
		$pager_html .= '<span class="paging-input"> ' . $current_page . ' ' . __('of', 'dk_speakup') . ' <span class="total-pages">' . $total_pages . ' </span></span>';
	}

	// next page and last page links
	if ( $current_page == $total_pages ) {
		$pager_html .= '<a class="next-page disabled" href="">&rsaquo;</a> ';
		$pager_html .= '<a class="last-page disabled" href="">&raquo;</a>';
	}
	else {
		$pager_html .= '<a class="next-page" href="' . $base_url . '&paged=' . ( $current_page + 1 ) . '&total_pages=' . $total_pages . '">&rsaquo;</a> ';
		$pager_html .= '<a class="last-page" href="' . $base_url . '&paged=' . $total_pages . '&total_pages=' . $total_pages . '">&raquo;</a>';
	}

	$pager_html .= '</form>';
	$pager_html .= '</div>';

	echo $pager_html;
}

/**
 * Cleans up values entered in the pager form on paged table view pages
 * Non-numeric values return page number to 1
 * Values larger than total available pages return highest available page number
 * returns a number
 *
 * @param $requested (int) number of the page requested for display
 * @param $total (int) total number of available pages (total rows / rows per page)
 */
function dk_speakup_current_paged( $requested, $total ) {
	// ensure only numeric values for page number
	$current_page = ( is_numeric( $requested ) ) ? $requested : '1';

	// ensure current page number doesn't exceed total number of pages
	if ( $current_page > $total ) {
		$current_page = $total;
	}

	return $current_page;
}

/**
 * Constructs progress bar used on Petitions table page in the admin
 *
 * @param $goal (int) signatures goal
 * @param $signatures (int) signatures collected so far
 * @param $max_width (int) width of the outer progress bar div in pixels
 */
function dk_speakup_admin_goal_progress( $goal, $signatures, $max_width) {
	if ( $goal != '0' ) {
		// figure out how wide the progress bar should be
		$width_multiplier = $max_width / 100;
		$percent_complete = floor( ( $signatures / $goal ) * 100 );
		$progressbar_width = ( $percent_complete > 100 ) ? $max_width : floor( $percent_complete * $width_multiplier );

		// set progress bar color via CSS class
		if ( $percent_complete < 20 ) {
			$color_class = 'dk-speakup-progressbar-low';
		}
		elseif ( $percent_complete < 80 ) {
			$color_class = 'dk-speakup-progressbar-medium';
		}
		else {
			$color_class = 'dk-speakup-progressbar-complete';
		}

		// draw the progress bar
		$progressbar = '<div class="dk_speakup_clear"></div><div class="dk-speakup-admin-progress" style="width: ' . $max_width . 'px;"><div class="dk-speakup-admin-progress-bar ' . $color_class . '" style="width: ' . $progressbar_width . 'px;"></div></div>';
		return number_format( $goal ) . $progressbar;
	}
	else {
		return '--';
	}
}

// generate CSV file for download
if ( isset( $_REQUEST['csv'] ) && $_REQUEST['csv'] == 'signatures' ) {
	// make sure it executes before headers are sent
	add_action( 'admin_menu', 'dk_speakup_signatures_csv' );
	function dk_speakup_signatures_csv() {
		// check security: ensure user has authority and intention
		if ( !current_user_can( 'publish_posts' ) ) wp_die( __('Insufficient privileges: You need to be an editor to do that.', 'dk_speakup') );
		check_admin_referer( 'dk_speakup-download_signatures' );

		$pid = isset( $_REQUEST['pid'] ) ? $_REQUEST['pid'] : ''; // petition id

		// get signatures from the database
		global $wpdb;
		$db_petitions = $wpdb->prefix . "dk_speakup_petitions";
		$db_signatures = $wpdb->prefix . "dk_speakup_signatures";

		// add AND clause to WHERE statement if pid is set (to query only signatures from a specific petition)
		$which_petition = ( $pid ) ? "AND $db_signatures.petitions_id = '$pid'" : '';
		$sql = "
			SELECT $db_signatures.id, $db_signatures.petitions_id, $db_signatures.first_name, $db_signatures.last_name, $db_signatures.email, $db_signatures.address, $db_signatures.date, $db_signatures.confirmed, $db_petitions.petition_title
			FROM `$db_signatures`, `$db_petitions`
			WHERE $db_signatures.petitions_id = $db_petitions.id $which_petition
			ORDER BY $db_signatures.id DESC
		";
		$results = $wpdb->get_results( $sql );

		$filename = ( $pid ) ? 'SpeakUp-signatures-' . $pid . '.csv' : 'SpeakUp-signatures-all.csv';

		// set up CSV file headers
		header( 'Content-Type: application/octet-stream' );
		header( 'Content-Disposition: attachment; filename="' . $filename . '"' );
		header( 'Pragma: public' ); // supposed to make stuff work over https

		// get the column headers translated
		$firstname = __( 'First Name', 'dk_speakup' );
		$lastname = __( 'Last Name', 'dk_speakup' );
		$email = __( 'Email Address', 'dk_speakup' );
		$address =  __( 'Address', 'dk_speakup' );
		$date = __( 'Date Signed', 'dk_speakup' );
		$confirmed = __( 'Confirmed', 'dk_speakup' );
		$petition_title = __( 'Petition Title', 'dk_speakup' );
		$petitions_id = __( 'Petition ID', 'dk_speakup' );

		// construct CSV file header row
		// must use double quotes
		$csv = "$firstname,$lastname,$email,$address,$date,$confirmed,$petition_title,$petitions_id";
		$csv .= "\n";

		// construct CSV file data rows
		foreach ( $results as $field ) {
			// convert the 1, 0, or '' values of confirmed to readable format
			$confirm = $field->confirmed;
			if ( $confirm == 1 ) {
				$confirm = __( 'confirmed', 'dk_speakup' );
			}
			elseif ( $confirm == 0 ) {
				$confirm = __( 'unconfirmed', 'dk_speakup' );
			}
			else {
				$confirm = '--';
			}
			$csv .=  '"' . $field->first_name . '","' . $field->last_name . '","' . $field->email . '","' . $field->address . '","' . $field->date . '","' . $confirm . '","' . html_entity_decode( $field->petition_title, ENT_QUOTES ) . '","' . $field->petitions_id . '"';
			$csv .= "\n";
		}

		// output CSV file
		echo $csv;
		exit;
	}
}

?>