<?php

// plugin installation routine
function dk_speakup_install() {
	global $wpdb;
	global $dk_speakup_version;

	// construct db table names
	$table_petitions = $wpdb->prefix . 'dk_speakup_petitions';
	$table_signatures = $wpdb->prefix . 'dk_speakup_signatures';

	$install_petitions = "
		CREATE TABLE $table_petitions (
		`id` BIGINT( 20 ) UNSIGNED NOT NULL AUTO_INCREMENT,
		`petition_title` TEXT NOT NULL,
		`petition_email` VARCHAR( 100 ) NOT NULL,
		`petition_subject` VARCHAR( 200 ) NOT NULL,
		`petition_greeting` VARCHAR( 200 ) NOT NULL,
		`petition_message` LONGTEXT NOT NULL,
		`display_address` CHAR( 1 ) BINARY NOT NULL,
		`expires` CHAR( 1 ) BINARY NOT NULL,
		`expiration_date` DATETIME NOT NULL,
		`created_date` DATETIME NOT NULL,
		`has_signature_goal` CHAR( 1 ) BINARY NOT NULL,
		`signature_goal` INT( 11 ) NOT NULL,
		`send_email` CHAR( 1 ) BINARY NOT NULL,
		`twitter_message` VARCHAR( 120 ) NOT NULL,
		`confirm` CHAR( 1 ) BINARY NOT NULL,
		UNIQUE KEY  ( `id` )
	);";

	$install_signatures = "
		CREATE TABLE $table_signatures (
		`id` BIGINT( 20 ) UNSIGNED NOT NULL AUTO_INCREMENT,
		`petitions_id` BIGINT( 20 ) NOT NULL,
		`first_name` VARCHAR( 200 ) NOT NULL,
		`last_name` VARCHAR( 200 ) NOT NULL,
		`email` VARCHAR( 200 ) NOT NULL,
		`address` VARCHAR( 200 ) NOT NULL,
		`date` DATETIME NOT NULL,
		`confirmation_code` VARCHAR( 32 ) NOT NULL,
		`confirmed` CHAR( 1 ) BINARY NOT NULL,
		UNIQUE KEY  ( `id` )
	);";

	// create database tables
	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta( $install_petitions );
	dbDelta( $install_signatures );

	// set default options
	$options = array(
		'petitions_rows' => '20',
		'signatures_rows' => '50',
		'petition_theme' => 'standard',
		'petition_header' => __( 'Sign the Petition', 'dk_speakup' ),
		'button_text' => __( 'Sign Now', 'dk_speakup' ),
		'expiration_message' => __( 'This petition is now closed.', 'dk_speakup' ),
		'success_message' => '<strong>' . __( 'Thank you', 'dk_speakup' ) . ', %first_name%.</strong><p>' . __( 'Your signature has been added.', 'dk_speakup' ) . '</p>',
		'already_signed_message' => __( 'This petition has already been signed using your email address.', 'dk_speakup'),
		'share_message' => __( 'Share this with your friends:', 'dk_speakup' ),
		'confirm_subject' => __( 'Petition signature: confirmation needed', 'dk_speakup' ),
		'confirm_message' => __( "Please confirm your email address by clicking the link below:", "dk_speakup" ) . "\r\n%confirmation_link%",
		'confirm_email' => get_bloginfo( 'name' ) . ' <' . get_bloginfo( 'admin_email' ) . '>'
	);
	// add plugin options to wp_options table
	add_option( 'dk_speakup_options', $options );
	add_option( 'dk_speakup_version', $dk_speakup_version );
}

// run plugin update script if needed
add_action( 'plugins_loaded', 'dk_speakup_update' );
function dk_speakup_update() {
	global $dk_speakup_version;

	$installed_version = get_option( 'dk_speakup_version' );
	$new_version = $dk_speakup_version;

	if ( $installed_version < 1.1 ) {
		dk_speakup_install();

		// update plugin options
		$old_options = get_option( 'dk_speakup_options' );
		$new_options = array(
			'confirm_subject' => __( 'Petition signature: confirmation needed', 'dk_speakup' ),
			'confirm_message' => __( "Please confirm your email address by clicking the link below:", "dk_speakup" ) . "\r\n%confirmation_link%",
			'confirm_email' => get_bloginfo( 'name' ) . ' <' . get_bloginfo( 'admin_email' ) . '>'
		);
		$merged_options = array_merge( $old_options, $new_options );
		update_option( 'dk_speakup_options', $merged_options );
	}

	// update plugin version tag in db
	if ( $installed_version != $new_version ) {
		update_option( 'dk_speakup_version', $new_version );
	}
}

// enable translations
add_action( 'init', 'dk_speakup_init' );
function dk_speakup_init() {
	load_plugin_textdomain( 'dk_speakup', false, 'speakup-email-petitions/languages' );
}

// create admin menus
add_action( 'admin_menu', 'dk_speakup_create_menus' );
function dk_speakup_create_menus() {
	// create Petitions page
	add_menu_page( __( 'Email Petitions', 'dk_speakup' ), __( 'Email Petitions', 'dk_speakup' ), 'publish_posts', 'dk_speakup', 'dk_speakup_petitions_page', plugins_url( 'speakup-email-petitions/images/blank.png' ) );
	// create Add New page
	add_submenu_page( 'dk_speakup', __( 'Add New' ), __( 'Add New' ), 'publish_posts', 'dk_speakup_edit', 'dk_speakup_edit_page' );
	// create Signatures page
	add_submenu_page( 'dk_speakup', __( 'Signatures', 'dk_speakup' ), __( 'Signatures', 'dk_speakup' ), 'publish_posts', 'dk_speakup_signatures', 'dk_speakup_signatures_page' );
	// create Settings page
	add_submenu_page( 'dk_speakup', __( 'Email Petitions Settings', 'dk_speakup' ), __( 'Settings', 'dk_speakup' ), 'manage_options', 'dk_speakup_settings', 'dk_speakup_settings_page' );
}

// display custom menu icon
add_action( 'admin_head', 'dk_speakup_menu_icon' );
function dk_speakup_menu_icon() {
	echo '
		<style type="text/css">
			#toplevel_page_dk_speakup .wp-menu-image {
				background: url(' . plugins_url( "speakup-email-petitions/images/icon-emailpetitions-16.png" ) . ') no-repeat 6px 7px !important;
			}
			#toplevel_page_dk_speakup:hover .wp-menu-image, #toplevel_page_dk_speakup.wp-has-current-submenu .wp-menu-image {
				background-position: 6px -17px !important;
			}
		</style>
	';
}

// load JavaScript for use on admin pages
add_action( 'admin_print_scripts', 'dk_speakup_admin_js' );
function dk_speakup_admin_js() {
	global $parent_file;

	// make sure scripts load only on this plugin's admin pages
	if ( $parent_file == 'dk_speakup' ) {
		wp_enqueue_script( 'dk_speakup_admin_js', plugins_url( 'speakup-email-petitions/js/admin.js' ), array( 'jquery' ) );
		wp_enqueue_script( 'post', admin_url( 'js/post.js' ), 'jquery' );
	}
}

// load CSS for use on admin pages
add_action( 'admin_print_styles', 'dk_speakup_admin_css' );
function dk_speakup_admin_css() {
	global $parent_file;

	// make sure styles load only on this plugin's admin pages
	if ( $parent_file == 'dk_speakup' ) {
		wp_enqueue_style( 'dk_speakup_admin_css', plugins_url( 'speakup-email-petitions/css/admin.css' ) );
	}
}

/**
 * Handle public petition form submissions
 * 
 * Petition form is submitted via AJAX
 * Then we determine whether to send a request for email confirmation
 * or to go ahead and send out the petition message email.
 * Then we add the signature to DB
 */
add_action( 'wp_ajax_dk_speakup_sendmail', 'dk_speakup_sendmail' );
add_action( 'wp_ajax_nopriv_dk_speakup_sendmail', 'dk_speakup_sendmail' );
function dk_speakup_sendmail() {
	global $wpdb;
	$options = get_option( 'dk_speakup_options' );
	$db_signatures = $wpdb->prefix . 'dk_speakup_signatures';
	$db_petitions = $wpdb->prefix . 'dk_speakup_petitions';

	$petitions_id = absint( $_POST['id'] );
	$first_name = esc_html( stripslashes( $_POST['first_name'] ) );
	$last_name = esc_html( stripslashes( $_POST['last_name'] ) );
	$email = esc_html( stripslashes( $_POST['email'] ) );
	$address = ( isset( $_POST['address'] ) ) ? esc_html( stripslashes( $_POST['address'] ) ) : '';
	$date = current_time( 'mysql', 0 );
	$email_headers = "From: " . $first_name . " " . $last_name . " <" . $email . ">" . "\r\n";
	$confirmation_code = '';
	$confirmed = '';

	// query to determine if submitted email address has already been used on this petition
	$sql_check = "
		SELECT `id`
		FROM $db_signatures
		WHERE `email` = '$email' AND `petitions_id` = '$petitions_id'
	";
	$results = $wpdb->get_row( $sql_check );

	// if email has already been used, disply error message
	if ( count( $results ) ) {
		echo $options['already_signed_message'];
	}
	// otherwise insert new signature in db, send email, and display thank you message
	else {
		// query petition data needed to send email
		$sql_select = "
			SELECT `petition_email`, `petition_subject`, `petition_greeting`, `petition_message`, `send_email`, `confirm`
			FROM $db_petitions
			WHERE `id` = '$petitions_id'
		";
		$petition = $wpdb->get_row( $sql_select );

		// if petition requires email confirmation, send confirmation message
		if ( $petition->confirm == '1' ) {
			// set signature to unconfirmed
			$confirmed = '0';
			// generate confirmation code
			$confirmation_code = substr( md5( uniqid() ), 0, 16 );
			// construct confirmation email messgae
			$confirmation_url = site_url() . '?dkspeakupconfirm=' . $confirmation_code;

			// set up the confrmation message based on option entered on settings page
			$confirmation_message = $options['confirm_message'];
				if ( strpos( $confirmation_message, '%confirmation_link%' ) == false ) {
					$confirmation_message = $confirmation_message .  "\r\n\r\n" . $confirmation_url;
				}
				$confirm_search = array( '%first_name%', '%last_name%', '%confirmation_link%' );
				$confirm_replace = array( $first_name, $last_name, $confirmation_url );
				$confirmation_message = str_replace( $confirm_search, $confirm_replace, $confirmation_message );
			$confirmation_subject = $options['confirm_subject'];
			$confirmation_headers = "From: " . $options['confirm_email'] . "\r\n";
			// send confirmation email
			wp_mail( $email, $confirmation_subject, $confirmation_message, $confirmation_headers );
		}
		// else, send the petition email to target address
		else {
			if ( $petition->send_email == '1' ) {
				// construct the email message body (adding the signature)
				$greeting = $petition->petition_greeting . "\r\n\r\n";
				$signature = "\r\n\r\n" . $first_name . " " . $last_name . "\r\n" . $email . "\r\n"  . $address . "\r\n";
				$message = html_entity_decode( $greeting . $message . $signature, ENT_QUOTES );
				// send the petition email
				wp_mail( $petition->petition_email, $petition->petition_subject, $message, $email_headers );
			}
		}

		// add signature to the signatures table
		$sql_insert = "
			INSERT into $db_signatures ( `petitions_id`, `first_name`, `last_name`, `email`, `address`, `date`, `confirmation_code`, `confirmed` )
			values ( '$petitions_id', '$first_name', '$last_name', '$email', '$address', '$date', '$confirmation_code', '$confirmed' )
		";
		$wpdb->query( $sql_insert );

		// display success message
		$success_message = $options['success_message'];
		$success_message = str_replace( '%first_name%', $first_name, $success_message );
		$success_message = str_replace( '%last_name%', $last_name, $success_message );
		echo $success_message;
	}

	die();
}

?>