<?php

// register shortcode to display public petition form
add_shortcode( 'emailpetition', 'dk_speakup_emailpetition_shortcode' );
function dk_speakup_emailpetition_shortcode( $attr ) {
	global $wpdb;
	// construct db table name
	$db_petitions = $wpdb->prefix . "dk_speakup_petitions";
	$db_signatures = $wpdb->prefix . "dk_speakup_signatures";

	$options = get_option( 'dk_speakup_options' );

	// only query a petition if the "id" attribute has been set
	if ( isset( $attr['id'] ) && is_numeric( $attr['id'] ) ) {
		$id = $attr['id'];
		$db_table = $wpdb->prefix . "dk_speakup_petitions";

		// get petition info and number of signatures
		$sql = "
			SELECT $db_petitions.id, $db_petitions.petition_message, $db_petitions.display_address, 
				$db_petitions.expires, $db_petitions.expiration_date, $db_petitions.twitter_message, 
				$db_petitions.signature_goal, $db_petitions.confirm, COUNT( $db_signatures.id ) AS 'signatures'
			FROM $db_petitions
			LEFT JOIN $db_signatures
				ON $db_petitions.id = $db_signatures.petitions_id
				AND ( $db_signatures.confirmed = '' OR $db_signatures.confirmed = '1' )
			WHERE $db_petitions.id = $attr[id]
			GROUP BY $db_petitions.id
		";
		$results = $wpdb->get_row( $sql );

		// if a petition with the specified id exists, try to display it
		if ( !empty( $results ) ) {

			// if petition has expired, display expiration notice
			$expired = ( $results->expires == '1' && time() >= strtotime( $results->expiration_date ) ) ? 1 : 0;
			$goal_text = ( $results->signature_goal != 0 ) ? '<div class="dk-speakup-expired-goal"><span>' . __( 'Signature goal', 'dk_speakup' ) . ':</span> ' . $results->signature_goal . '</div>' : '';

			if ( $expired ) {
				$petition_form = '
					<div class="dk-speakup-petition-wrap" id="dk-speakup-petition-' . $results->id . '">
						<h3>' . $options['petition_header'] . '</h3>
						<div class="dk-speakup-notice">
							<p>' . $options['expiration_message'] . '</p>
							<div class="dk-speakup-expired-deadline">
								<span>' . __( 'End date', 'dk_speakup' ) . ':</span> ' . date( 'M d, Y', strtotime( $results->expiration_date ) ) . '
							</div>
							<div class="dk-speakup-expired-signatures">
								<span>' . __( 'Signatures collected', 'dk_speakup' ) . ':</span> ' . $results->signatures . '
							</div>
							' . $goal_text . '
						</div>
						' . dk_speakup_public_goal_progress( $results->signature_goal, $results->signatures, 250, 0 ) . '
					</div>
				';
			}
			// else display petition form
			else {
				if( $results->display_address == '1' ) {
					$address_field = '
						<div class="dk-speakup-address-wrap">
							<label for="dk-speakup-address-' . $results->id . '">' . __( 'Address', 'dk_speakup' ) . '</label>
							<textarea name="dk-speakup-address" id="dk-speakup-address-' . $results->id . '" class="dk-speakup-input dk-speakup-address" value="" type="text" /></textarea>
						</div>
					';
				}
				else {
					$address_field = '';
				}

				$petition_form = '
					<div class="dk-speakup-petition-wrap" id="dk-speakup-petition-' . $results->id . '">
						<h3>' . $options['petition_header'] . '</h3>
						<div class="dk-speakup-response"></div>
						<form class="dk-speakup-petition">
							<input type="hidden" name="dk-speakup-id" class="dk-speakup-id" value="' . $results->id . '" />
							<input type="hidden" class="dk-speakup-permalink" value="' . get_permalink() .'" />
							<input type="hidden" class="dk-speakup-posttitle" value="' . esc_attr( urlencode( get_the_title() ) ) .'" />
							<input type="hidden" class="dk-speakup-twitter-message" value="' . urlencode( $results->twitter_message ) .'" />
							<div class="dk-speakup-first-name-wrap">
								<label for="dk-speakup-first-name-' . $results->id . '">' . __( 'First Name', 'dk_speakup' ) . '</label>
								<input name="dk-speakup-first-name" id="dk-speakup-first-name-' . $results->id . '" class="dk-speakup-input dk-speakup-first-name" value="" type="text" />
							</div>
							<div class="dk-speakup-last-name-wrap">
								<label for="dk-speakup-last-name-' . $results->id . '">' . __( 'Last Name', 'dk_speakup' ) . '</label>
								<input name="dk-speakup-last-name" id="dk-speakup-last-name-' . $results->id . '" class="dk-speakup-input dk-speakup-last-name" value="" type="text" />
							</div>
							<div class="dk-speakup-email-wrap">
								<label for="dk-speakup-email-' . $results->id . '">' . __( 'Email', 'dk_speakup' ) . '</label>
								<input name="dk-speakup-email" id="dk-speakup-email-' . $results->id . '" class="dk-speakup-input dk-speakup-email" value="" type="email" />
							</div>
							' . $address_field . '
							<div class="dk-speakup-message-wrap">
								<textarea name="dk-speakup-message" id="dk-speakup-message-' . $results->id . '" class="dk-speakup-message">' . $results->petition_message . '</textarea>
							</div>
							<div class="dk-speakup-submit-wrap">
								<a href="#dk-speakup-petition-' . $results->id . '" class="dk-speakup-submit" /><span>' . $options['button_text'] . '</span></a>
							</div>
							' . dk_speakup_public_goal_progress( $results->signature_goal, $results->signatures, 150 ) . '
						</form>
						<div class="dk-speakup-share">
							<p><strong>' . $share_message = $options['share_message'] . '</strong></p>
							<a class="dk-speakup-facebook" href="#" title="Facebook" class="dk-speakup-facebook"></a>
							<a class="dk-speakup-twitter" href="#" title="Twitter" class="dk-speakup-twitter"></a>
							<div class="dk-speakup-clear"></div>
						</div>
					</div>
				';
			}

		}
		// otherwise, display nothing
		// most likely scenario is a user deletes an old petition, but fails to remove shortcode from their post
		else {
			$petition_form = '';
		}
	}

	// if id attribute is left out, as in [emailpetition], display error
	else {
		$petition_form = '
			<div class="dk-speakup-petition-wrap">
				<div class="dk-speakup-notice">
					<p><strong>SpeakUp! Email Petitions</strong></p>
					<p>' . __( 'Error: You must include a valid id.', 'dk_speakup' ) . '</p>
				</div>
			</div>
		';
	}

	return $petition_form;
}

// load public CSS only on pages/posts that contain the [emailpetition] shortcode
add_filter( 'the_posts', 'dk_speakup_public_css_js' );
function dk_speakup_public_css_js( $posts ) {
	// ignore if there are no posts
	if ( empty( $posts ) ) return $posts;

	$options = get_option( 'dk_speakup_options' );

	// set flag to determine if post contains shortcode
	$shortcode_found = false;

	foreach ( $posts as $post ) {
		// if post content contains the shortcode
		if ( strstr( $post->post_content, '[emailpetition' ) ) {
			// update flag
			$shortcode_found = true;
			break;
		}
	}

	// if flag is now true, load the CSS and JavaScript once
	if ( $shortcode_found ) {
		if ( $options['petition_theme'] == 'standard' ) {
			wp_enqueue_style( 'dk_speakup_css', plugins_url( 'speakup-email-petitions/css/theme-standard.css' ) );
		}
		wp_enqueue_script( 'dk_speakup_js', plugins_url( 'speakup-email-petitions/js/public.js' ), array( 'jquery' ) );

		// make sure ajax callback url works on both https and http
		$protocol = isset( $_SERVER['HTTPS'] ) ? 'https://' : 'http://';
		$params = array(
			'ajaxurl' => admin_url( 'admin-ajax.php', $protocol )
		);
		wp_localize_script( 'dk_speakup_js', 'dk_speakup_js', $params );
	}

	return $posts;
}


/**
 * Constructs progress bar used on Petitions table page in the admin
 *
 * @param $goal (int) signatures goal
 * @param $signatures (int) signatures collected so far
 * @param $max_width (int) width of the outer progress bar div in pixels
 * @param $show_text (bool) whether to display leading text
 */
function dk_speakup_public_goal_progress( $goal, $signatures, $max_width, $show_text = 1) {
	if ( $goal != '0' ) {
		// figure out how wide the progress bar should be
		$width_multiplier = $max_width / 100;
		$percent_complete = floor( ( $signatures / $goal ) * 100 );
		$progressbar_width = ( $percent_complete > 100 ) ? $max_width : floor( $percent_complete * $width_multiplier );

		// set progress bar color via CSS class
		if ( $percent_complete < 20 ) {
			$color_class = 'dk-speakup-progressbar-low';
		}
		elseif ( $percent_complete < 80 ) {
			$color_class = 'dk-speakup-progressbar-medium';
		}
		else {
			$color_class = 'dk-speakup-progressbar-complete';
		}

		// pluralize "signature"
		$sig_text = ( $signatures == 1 ) ? __( 'signature', 'dk_speakup' ) : __( 'signatures', 'dk_speakup' );

		if ( $show_text == 1 ) {
			$sig_text = '<div class="dk-speakup-signature-count"><span>' . number_format( $signatures ) . '</span> ' . $sig_text . '</div>';
		}
		else {
			$sig_text = '';
		}

		// draw the progress bar
		$progressbar = '
			<div class="dk-speakup-progress-wrap">
				' . $sig_text . '
				<div class="dk-speakup-progress" style="width: ' . $max_width . 'px;">
					<div class="dk-speakup-progressbar ' . $color_class . '" style="width: ' . $progressbar_width . 'px;"></div>
				</div>
				<div class="dk-speakup-clear"></div>
			</div>
		';
		return $progressbar;
	}
	else {
		return '';
	}
}

// capture requests from links clicked in confirmation emails
if ( isset( $_REQUEST['dkspeakupconfirm'] ) ) {
	add_action( 'template_redirect', 'dk_speakup_confirm_email' );
}
/**
 * Gets request variable passed from links clicked in confirmation emails
 * and check for match in signatures db table.
 * If match is found, set signature to confirmed and send petition email
 * Then display confirmation status message
 */
function dk_speakup_confirm_email() {
	global $wpdb;
	$petitions_table = $wpdb->prefix . 'dk_speakup_petitions';
	$signatures_table = $wpdb->prefix . 'dk_speakup_signatures';

	// get the confirmation code from url
	$confirmation_code = $_REQUEST['dkspeakupconfirm'];

	// try to confirm the signature
	$confirmation_sql = "
		UPDATE $signatures_table
		SET `confirmed` = '1'
		WHERE `confirmation_code` = '$confirmation_code'
	";
	$confirmation_result = $wpdb->query( $confirmation_sql );

	// if a match for the conformation code exists,
	// show message and send out the petition email
	if ( $confirmation_result > 0 ) {
		// figure out which petition the signature we confirmed belongs to
		$signature_data = "
			SELECT petitions_id, first_name, last_name, email, address
			FROM $signatures_table
			WHERE `confirmation_code` = '$confirmation_code' AND `confirmed` = '1'
		";
		$signature = $wpdb->get_row( $signature_data );

		// get the petition data needed to send email
		$petition_data = "
			SELECT `petition_email`, `petition_subject`, `petition_greeting`, `petition_message`, `send_email`, `confirm`
			FROM $petitions_table
			WHERE `id` = '$signature->petitions_id'
		";
		$petition = $wpdb->get_row( $petition_data );

		// if the "Don't send email" option was left unchecked...
		if ( $petition->send_email == '1' ) {
			// values from signatures table get used twice below, so need to convert them to PHP variables
			$first_name = $signature->first_name;
			$last_name = $signature->last_name;
			$email = $signature->email;
			$address = $signature->address;

			// construct the petition email message
			$greeting = $petition->petition_greeting . "\r\n\r\n";
			$signature = "\r\n\r\n" . $first_name . " " . $last_name . "\r\n" . $email . "\r\n"  . $address . "\r\n";
			$message = html_entity_decode( $greeting . $petition->petition_message . $signature, ENT_QUOTES );
			$email_headers = "From: " . $first_name . " " . $last_name . " <" . $email . ">" . "\r\n";
			// send the email
			wp_mail( $petition->petition_email, $petition->petition_subject, $message, $email_headers );
		}
		// set up the confirmation status message
		$message = __( 'Thank you. Your signature has been added to the petition.', 'dk_speakup' );
	}
	// else, check if the signature has already been confirmed
	else {
		$confirmed_sql = "
			SELECT id
			FROM $signatures_table
			WHERE `confirmation_code` = '$confirmation_code' AND `confirmed` = '1'
		";
		$confirmed_result = $wpdb->get_row( $confirmed_sql );
		// if signature already confirmed...
		if ( count( $confirmed_result ) > 0 ) {
			$message = __( 'Your signature has already been confirmed.', 'dk_speakup' );
		}
		// else, the confirmation code is fubar
		// or the admin has already deleted the signature
		else {
			$message = __( 'The confirmation code you provided is invalid.', 'dk_speakup' );
		}
	}
	// construct page for displaying confirmation status message
	$confirmation_page = '
		<!DOCTYPE html>
		<html>
		<head>
			<meta http-equiv="Content-Type" content="text/xhtml; charset=' . get_bloginfo( "charset" ) . '" />
			<meta http-equiv="refresh" content="10;' . site_url() . '"> 
			<title>' . get_bloginfo( "name" ) . '</title>
		</head>
		<body>
			<div style="width: 500px; margin: 2em auto 0 auto;font-size: 14px;font-family: arial, sans-serif;">
				<h2>' . __( "Email Confirmation", "dk_speakup" ) . '</h2>
				<p>' . $message . '</p>
				<p>' . __( "You will be redirected momentarily.", "dk_speakup" ) . '</p>
				<p><a href="' . site_url() . '">' . get_bloginfo( "name" ) . '</a></p>
			</div>
		</body>
		</html>
	';
	// display confirmation status message
	echo $confirmation_page;

	// stop page rendering here
	// without this, the home page will display below the confirmation message
	die();
}
?>